
## Sobre o a verso web

para que o desenvolvimento de aplicativos que exigem alto intendimento de contextos especificos e complexos é necessario que tenhamos nosso agentes para facil inferencia via web apesar de um app nativo seja incrivel é bem limitado quando se trata de sistemas de conversas em tempo real o ate mesmo previsualizadores em tempo real 

#


